[![Tests](https://github.com/physicspenguin/cga-py/actions/workflows/tests.yml/badge.svg)](https://github.com/physicspenguin/cga-py/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/physicspenguin/cga-py/branch/master/graph/badge.svg?token=129CMVB1AQ)](https://codecov.io/gh/physicspenguin/cga-py)

# cga_py

cga_py is an implementation of conformal geometric algebra (CGA) for python.

Currently still in heavy development.

## Install
```
pip install cga-py
```

## Usage
### As Package
See tutorial.py

A full documentation is still in progress.

### As Visualization Tool
In your console execute the following command.
```
cga_py_vis.py
```
This will open the visualization interface.
All relevant parameters can be adjusted.
After adjustment of the parameters do not forget to update the specific parameter groups
or best the whole application.

A full documentation of this tool and its capabilities will follow.
